public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2008-03-30 16:51 Mike Frysinger (vapier)
  0 siblings, 0 replies; 13+ messages in thread
From: Mike Frysinger (vapier) @ 2008-03-30 16:51 UTC (permalink / raw
  To: gentoo-commits

vapier      08/03/30 16:51:40

  Modified:             bootstrap.sh
  Log:
  convert virtual/baselayout to sys-apps/baselayout

Revision  Changes    Path
1.87                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?rev=1.87&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?rev=1.87&content-type=text/plain
diff : http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?r1=1.86&r2=1.87

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.86
retrieving revision 1.87
diff -u -r1.86 -r1.87
--- bootstrap.sh	31 Aug 2007 17:14:33 -0000	1.86
+++ bootstrap.sh	30 Mar 2008 16:51:39 -0000	1.87
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.86 2007/08/31 17:14:33 wolf31o2 Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.87 2008/03/30 16:51:39 vapier Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.86 2007/08/31 17:14:33 wolf31o2 Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.87 2008/03/30 16:51:39 vapier Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -259,7 +259,7 @@
 n=${n%%-[0-9]*}; echo "my$(tr a-z- A-Z_ <<<$n)=$p; "; done)
 
 # This stuff should never fail but will if not enough is installed.
-[[ -z ${myBASELAYOUT} ]] && myBASELAYOUT=">=$(portageq best_version / virtual/baselayout)"
+[[ -z ${myBASELAYOUT} ]] && myBASELAYOUT=">=$(portageq best_version / sys-apps/baselayout)"
 [[ -z ${myPORTAGE}    ]] && myPORTAGE="portage"
 [[ -z ${myBINUTILS}   ]] && myBINUTILS="binutils"
 [[ -z ${myGCC}        ]] && myGCC="gcc"



-- 
gentoo-commits@lists.gentoo.org mailing list



^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2009-08-06 22:21 Zac Medico (zmedico)
  0 siblings, 0 replies; 13+ messages in thread
From: Zac Medico (zmedico) @ 2009-08-06 22:21 UTC (permalink / raw
  To: gentoo-commits

zmedico     09/08/06 22:21:16

  Modified:             bootstrap.sh
  Log:
  Fix portage.settings.packages code for compatibility with unicode strings.

Revision  Changes    Path
1.88                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?rev=1.88&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?rev=1.88&content-type=text/plain
diff : http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?r1=1.87&r2=1.88

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.87
retrieving revision 1.88
diff -u -r1.87 -r1.88
--- bootstrap.sh	30 Mar 2008 16:51:39 -0000	1.87
+++ bootstrap.sh	6 Aug 2009 22:21:16 -0000	1.88
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.87 2008/03/30 16:51:39 vapier Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.88 2009/08/06 22:21:16 zmedico Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.87 2008/03/30 16:51:39 vapier Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.88 2009/08/06 22:21:16 zmedico Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -254,7 +254,7 @@
 # parents.  So we now call portage to read the aggregate profile and store
 # that into a variable.
 
-eval $(pycmd 'import portage; print portage.settings.packages;' |
+eval $(pycmd 'import portage; print [str(x) for x in portage.settings.packages];' |
 sed 's/[][,]//g; s/\*//g' | tr ' ' '\n' | while read p; do n=${p##*/}; n=${n%\'};
 n=${n%%-[0-9]*}; echo "my$(tr a-z- A-Z_ <<<$n)=$p; "; done)
 






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2009-09-25  5:17 Zac Medico (zmedico)
  0 siblings, 0 replies; 13+ messages in thread
From: Zac Medico (zmedico) @ 2009-09-25  5:17 UTC (permalink / raw
  To: gentoo-commits

zmedico     09/09/25 05:17:39

  Modified:             bootstrap.sh
  Log:
  Fix python syntax for python 3 compatibility.

Revision  Changes    Path
1.89                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?rev=1.89&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?rev=1.89&content-type=text/plain
diff : http://sources.gentoo.org/viewcvs.py/gentoo-x86/scripts/bootstrap.sh?r1=1.88&r2=1.89

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.88
retrieving revision 1.89
diff -u -r1.88 -r1.89
--- bootstrap.sh	6 Aug 2009 22:21:16 -0000	1.88
+++ bootstrap.sh	25 Sep 2009 05:17:39 -0000	1.89
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.88 2009/08/06 22:21:16 zmedico Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.89 2009/09/25 05:17:39 zmedico Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.88 2009/08/06 22:21:16 zmedico Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.89 2009/09/25 05:17:39 zmedico Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -254,7 +254,7 @@
 # parents.  So we now call portage to read the aggregate profile and store
 # that into a variable.
 
-eval $(pycmd 'import portage; print [str(x) for x in portage.settings.packages];' |
+eval $(pycmd 'import portage, sys; sys.stdout.write(str([str(x) for x in portage.settings.packages]));' |
 sed 's/[][,]//g; s/\*//g' | tr ' ' '\n' | while read p; do n=${p##*/}; n=${n%\'};
 n=${n%%-[0-9]*}; echo "my$(tr a-z- A-Z_ <<<$n)=$p; "; done)
 
@@ -302,7 +302,7 @@
 	CFLAGS CHOST CXXFLAGS MAKEOPTS ACCEPT_KEYWORDS PROXY HTTP_PROXY
 	FTP_PROXY FEATURES STAGE1_USE"
 
-eval $(python -c 'import portage,os,string;	print "\n".join(["export %s=\"%s\"; [[ -z \"%s\" ]] || einfo %s=\\\"%s\\\";" % (k, portage.settings[k], portage.settings[k], k, portage.settings[k]) for k in os.getenv("ENV_EXPORTS").split()])')
+eval $(python -c 'import portage, os, sys; sys.stdout.write("".join(["export %s=\"%s\"; [[ -z \"%s\" ]] || einfo %s=\\\"%s\\\";\n" % (k, portage.settings[k], portage.settings[k], k, portage.settings[k]) for k in os.getenv("ENV_EXPORTS").split()]))')
 unset ENV_EXPORTS
 
 echo -------------------------------------------------------------------------------






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2010-09-11 17:06 Zac Medico (zmedico)
  0 siblings, 0 replies; 13+ messages in thread
From: Zac Medico (zmedico) @ 2010-09-11 17:06 UTC (permalink / raw
  To: gentoo-commits

zmedico     10/09/11 17:06:47

  Modified:             bootstrap.sh
  Log:
  Bug #273660 - Add a --quiet option for bootstrap.sh. Thanks to Alexandre Nuno Milheiro <nunomilheiro@gmail.com> for this patch.

Revision  Changes    Path
1.90                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.90&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.90&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.89&r2=1.90

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.89
retrieving revision 1.90
diff -u -r1.89 -r1.90
--- bootstrap.sh	25 Sep 2009 05:17:39 -0000	1.89
+++ bootstrap.sh	11 Sep 2010 17:06:47 -0000	1.90
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.89 2009/09/25 05:17:39 zmedico Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.90 2010/09/11 17:06:47 zmedico Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.89 2009/09/25 05:17:39 zmedico Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.90 2010/09/11 17:06:47 zmedico Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -64,6 +64,7 @@
 	echo -e "  ${GOOD}--fetchonly (-f)${NORMAL} Just download all the source files"
 	echo -e "  ${GOOD}--info (-i)${NORMAL}      Show system related information"
 	echo -e "  ${GOOD}--pretend (-p)${NORMAL}   Display the packages that will be merged"
+	echo -e "  ${GOOD}--quiet (-q)${NORMAL}     Reduced or condensed output from portage's displays."
 	echo -e "  ${GOOD}--tree (-t)${NORMAL}      Display the dependency tree, forces -p"
 	echo -e "  ${GOOD}--resume (-r)${NORMAL}    Build/use binary packages"
 }
@@ -85,6 +86,7 @@
 		--debug|-d)   STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} --debug"; DEBUG=1;;
 		--info|-i)    STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} --info" ; unset STRAP_RUN ;;
 		--pretend|-p) STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} -p"     ; unset STRAP_RUN ;;
+		--quiet|-q)   STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} -q"     ; unset STRAP_RUN ;;
 		--tree|-t)    STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} -p -t"  ; unset STRAP_RUN ;;
 		--resume|-r)  STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} --usepkg --buildpkg";;
 		--verbose|-v) STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} -v"; V_ECHO=v_echo;;






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2011-05-20  3:05 Jorge Manuel B. S. Vicetto (jmbsvicetto)
  0 siblings, 0 replies; 13+ messages in thread
From: Jorge Manuel B. S. Vicetto (jmbsvicetto) @ 2011-05-20  3:05 UTC (permalink / raw
  To: gentoo-commits

jmbsvicetto    11/05/20 03:05:33

  Modified:             bootstrap.sh
  Log:
  Applied Zac's path in bug 113298 to get stages building again.

Revision  Changes    Path
1.91                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.91&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.91&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.90&r2=1.91

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.90
retrieving revision 1.91
diff -u -r1.90 -r1.91
--- bootstrap.sh	11 Sep 2010 17:06:47 -0000	1.90
+++ bootstrap.sh	20 May 2011 03:05:33 -0000	1.91
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.90 2010/09/11 17:06:47 zmedico Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.91 2011/05/20 03:05:33 jmbsvicetto Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.90 2010/09/11 17:06:47 zmedico Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.91 2011/05/20 03:05:33 jmbsvicetto Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -262,6 +262,7 @@
 
 # This stuff should never fail but will if not enough is installed.
 [[ -z ${myBASELAYOUT} ]] && myBASELAYOUT=">=$(portageq best_version / sys-apps/baselayout)"
+[[ -z ${mySHADOW}     ]] && mySHADOW=">=$(portageq best_version / sys-apps/shadow)"
 [[ -z ${myPORTAGE}    ]] && myPORTAGE="portage"
 [[ -z ${myBINUTILS}   ]] && myBINUTILS="binutils"
 [[ -z ${myGCC}        ]] && myGCC="gcc"
@@ -285,6 +286,7 @@
 [[ -z ${myOS_HEADERS} ]] && myOS_HEADERS="virtual/os-headers"
 
 einfo "Using baselayout : ${myBASELAYOUT}"
+einfo "Using shadow     : ${mySHADOW}"
 einfo "Using portage    : ${myPORTAGE}"
 einfo "Using os-headers : ${myOS_HEADERS}"
 einfo "Using binutils   : ${myBINUTILS}"
@@ -345,7 +347,7 @@
 		:
 	fi
 	${V_ECHO} emerge ${STRAP_EMERGE_OPTS} ${myOS_HEADERS} ${myTEXINFO} ${myGETTEXT} ${myBINUTILS} \
-		${myGCC} ${myLIBC} ${myBASELAYOUT} ${myZLIB} || cleanup 1
+		${myGCC} ${myLIBC} ${myBASELAYOUT} ${mySHADOW} ${myZLIB} || cleanup 1
 	echo -------------------------------------------------------------------------------
 	set_bootstrap_stage 3
 fi






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2011-07-14  1:24 Jorge Manuel B. S. Vicetto (jmbsvicetto)
  0 siblings, 0 replies; 13+ messages in thread
From: Jorge Manuel B. S. Vicetto (jmbsvicetto) @ 2011-07-14  1:24 UTC (permalink / raw
  To: gentoo-commits

jmbsvicetto    11/07/14 01:24:53

  Modified:             bootstrap.sh
  Log:
  Reverted Zac's patch from bug 113298 as sys-apps/shadow is now part of packages.build.

Revision  Changes    Path
1.92                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.92&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.92&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.91&r2=1.92

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.91
retrieving revision 1.92
diff -u -r1.91 -r1.92
--- bootstrap.sh	20 May 2011 03:05:33 -0000	1.91
+++ bootstrap.sh	14 Jul 2011 01:24:53 -0000	1.92
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.91 2011/05/20 03:05:33 jmbsvicetto Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.92 2011/07/14 01:24:53 jmbsvicetto Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.91 2011/05/20 03:05:33 jmbsvicetto Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.92 2011/07/14 01:24:53 jmbsvicetto Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -262,7 +262,6 @@
 
 # This stuff should never fail but will if not enough is installed.
 [[ -z ${myBASELAYOUT} ]] && myBASELAYOUT=">=$(portageq best_version / sys-apps/baselayout)"
-[[ -z ${mySHADOW}     ]] && mySHADOW=">=$(portageq best_version / sys-apps/shadow)"
 [[ -z ${myPORTAGE}    ]] && myPORTAGE="portage"
 [[ -z ${myBINUTILS}   ]] && myBINUTILS="binutils"
 [[ -z ${myGCC}        ]] && myGCC="gcc"
@@ -286,7 +285,6 @@
 [[ -z ${myOS_HEADERS} ]] && myOS_HEADERS="virtual/os-headers"
 
 einfo "Using baselayout : ${myBASELAYOUT}"
-einfo "Using shadow     : ${mySHADOW}"
 einfo "Using portage    : ${myPORTAGE}"
 einfo "Using os-headers : ${myOS_HEADERS}"
 einfo "Using binutils   : ${myBINUTILS}"
@@ -347,7 +345,7 @@
 		:
 	fi
 	${V_ECHO} emerge ${STRAP_EMERGE_OPTS} ${myOS_HEADERS} ${myTEXINFO} ${myGETTEXT} ${myBINUTILS} \
-		${myGCC} ${myLIBC} ${myBASELAYOUT} ${mySHADOW} ${myZLIB} || cleanup 1
+		${myGCC} ${myLIBC} ${myBASELAYOUT} ${myZLIB} || cleanup 1
 	echo -------------------------------------------------------------------------------
 	set_bootstrap_stage 3
 fi






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2011-07-14 19:19 Zac Medico (zmedico)
  0 siblings, 0 replies; 13+ messages in thread
From: Zac Medico (zmedico) @ 2011-07-14 19:19 UTC (permalink / raw
  To: gentoo-commits

zmedico     11/07/14 19:19:03

  Modified:             bootstrap.sh
  Log:
  bootstrap.sh: remove make.conf backup code
  
  This code was intended to make backups of make.conf and variables it
  contained, but the code to overwrite make.conf no longer exists.
  Therefore, there's no reason to backup make.conf or its variables.

Revision  Changes    Path
1.93                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.93&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.93&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.92&r2=1.93

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.92
retrieving revision 1.93
diff -u -r1.92 -r1.93
--- bootstrap.sh	14 Jul 2011 01:24:53 -0000	1.92
+++ bootstrap.sh	14 Jul 2011 19:19:02 -0000	1.93
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.92 2011/07/14 01:24:53 jmbsvicetto Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.93 2011/07/14 19:19:02 zmedico Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.92 2011/07/14 01:24:53 jmbsvicetto Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.93 2011/07/14 19:19:02 zmedico Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -151,9 +151,6 @@
 
 cleanup() {
 	if [[ -n ${STRAP_RUN} ]] ; then
-		if [[ -f /etc/make.conf.build ]] ; then
-			mv -f /etc/make.conf.build /etc/make.conf
-		fi
 		if [ ${BOOTSTRAP_STAGE} -le 2 ] ; then
 			cp -f /var/cache/edb/mtimedb /var/run/bootstrap-mtimedb
 		else
@@ -168,10 +165,6 @@
 	/usr/bin/python -c "$@"
 }
 
-# Trap ctrl-c and stuff.  This should fix the users make.conf
-# not being restored.
-[[ -n ${STRAP_RUN} ]] && cp -f /etc/make.conf /etc/make.conf.build
-
 # TSTP messes ^Z of bootstrap up, so we don't trap it anymore.
 trap "cleanup" TERM KILL INT QUIT ABRT
 
@@ -296,17 +289,6 @@
 einfo "Using ncurses    : ${myNCURSES}"
 echo -------------------------------------------------------------------------------
 show_status 1 Configuring environment
-
-# Get correct CFLAGS, CHOST, CXXFLAGS, MAKEOPTS since make.conf will be
-# overwritten.
-
-export ENV_EXPORTS="GENTOO_MIRRORS PORTDIR DISTDIR PKGDIR PORTAGE_TMPDIR
-	CFLAGS CHOST CXXFLAGS MAKEOPTS ACCEPT_KEYWORDS PROXY HTTP_PROXY
-	FTP_PROXY FEATURES STAGE1_USE"
-
-eval $(python -c 'import portage, os, sys; sys.stdout.write("".join(["export %s=\"%s\"; [[ -z \"%s\" ]] || einfo %s=\\\"%s\\\";\n" % (k, portage.settings[k], portage.settings[k], k, portage.settings[k]) for k in os.getenv("ENV_EXPORTS").split()]))')
-unset ENV_EXPORTS
-
 echo -------------------------------------------------------------------------------
 
 [[ -x /usr/sbin/gcc-config ]] && GCC_CONFIG="/usr/sbin/gcc-config"
@@ -322,6 +304,9 @@
 # disable collision-protection
 export FEATURES="${FEATURES} -collision-protect"
 
+# query STAGE1_USE from the profile
+STAGE1_USE=$(portageq envvar STAGE1_USE)
+
 if [ ${BOOTSTRAP_STAGE} -le 1 ] ; then
 	show_status 2 Updating portage
 	${V_ECHO} USE="-* build bootstrap ${ALLOWED_USE} ${STAGE1_USE}" emerge ${STRAP_EMERGE_OPTS} ${myPORTAGE} || cleanup 1
@@ -370,5 +355,4 @@
 	echo
 fi
 
-# Restore original make.conf
 cleanup 0






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2011-11-17  1:51 Jorge Manuel B. S. Vicetto (jmbsvicetto)
  0 siblings, 0 replies; 13+ messages in thread
From: Jorge Manuel B. S. Vicetto (jmbsvicetto) @ 2011-11-17  1:51 UTC (permalink / raw
  To: gentoo-commits

jmbsvicetto    11/11/17 01:51:06

  Modified:             bootstrap.sh
  Log:
  Update bootstrap.sh to replace STAGE1_USE with BOOTSTRAP_USE - bug 390701.

Revision  Changes    Path
1.94                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.94&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.94&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.94&r2=1.95

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.94
retrieving revision 1.95
diff -u -r1.94 -r1.95
--- bootstrap.sh	17 Nov 2011 01:51:06 -0000	1.94
+++ bootstrap.sh	7 Jul 2012 03:34:53 -0000	1.95
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.94 2011/11/17 01:51:06 jmbsvicetto Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.95 2012/07/07 03:34:53 vapier Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.94 2011/11/17 01:51:06 jmbsvicetto Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.95 2012/07/07 03:34:53 vapier Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -119,11 +119,15 @@
 	export BOOTSTRAP_STAGE=0
 fi
 
-if type -P realpath > /dev/null ; then
-    MYPROFILEDIR=$(realpath /etc/make.profile)
-else
-    MYPROFILEDIR=$(readlink -f /etc/make.profile)
-fi
+for p in /etc/portage /etc ; do
+	p+="/make.profile"
+	[[ -e ${p} ]] || continue
+	if type -P realpath >/dev/null ; then
+		MYPROFILEDIR=$(realpath ${p})
+	else
+		MYPROFILEDIR=$(readlink -f ${p})
+	fi
+done
 if [[ ! -d ${MYPROFILEDIR} ]] ; then
 	eerror "Error:  '${MYPROFILEDIR}' does not exist.  Exiting."
 	exit 1






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2012-10-23  2:25 Zac Medico (zmedico)
  0 siblings, 0 replies; 13+ messages in thread
From: Zac Medico (zmedico) @ 2012-10-23  2:25 UTC (permalink / raw
  To: gentoo-commits

zmedico     12/10/23 02:25:23

  Modified:             bootstrap.sh
  Log:
  Fix profile packages parsing code for bug #439282.

Revision  Changes    Path
1.96                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.96&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.96&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.95&r2=1.96

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.95
retrieving revision 1.96
diff -u -r1.95 -r1.96
--- bootstrap.sh	7 Jul 2012 03:34:53 -0000	1.95
+++ bootstrap.sh	23 Oct 2012 02:25:23 -0000	1.96
@@ -1,7 +1,7 @@
 #!/bin/bash
-# Copyright 1999-2007 Gentoo Foundation
+# Copyright 1999-2012 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.95 2012/07/07 03:34:53 vapier Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.96 2012/10/23 02:25:23 zmedico Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.95 2012/07/07 03:34:53 vapier Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.96 2012/10/23 02:25:23 zmedico Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -253,9 +253,15 @@
 # parents.  So we now call portage to read the aggregate profile and store
 # that into a variable.
 
-eval $(pycmd 'import portage, sys; sys.stdout.write(str([str(x) for x in portage.settings.packages]));' |
-sed 's/[][,]//g; s/\*//g' | tr ' ' '\n' | while read p; do n=${p##*/}; n=${n%\'};
-n=${n%%-[0-9]*}; echo "my$(tr a-z- A-Z_ <<<$n)=$p; "; done)
+eval $(pycmd '
+import portage
+import sys
+for atom in portage.settings.packages:
+	if not isinstance(atom, portage.dep.Atom):
+		atom = portage.dep.Atom(atom.lstrip("*"))
+	varname = "my" + portage.catsplit(atom.cp)[1].upper().replace("-", "_")
+	sys.stdout.write("%s=\"%s\"; " % (varname, atom))
+')
 
 # This stuff should never fail but will if not enough is installed.
 [[ -z ${myBASELAYOUT} ]] && myBASELAYOUT=">=$(portageq best_version / sys-apps/baselayout)"





^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2013-06-27 21:04 Zac Medico (zmedico)
  0 siblings, 0 replies; 13+ messages in thread
From: Zac Medico (zmedico) @ 2013-06-27 21:04 UTC (permalink / raw
  To: gentoo-commits

zmedico     13/06/27 21:04:49

  Modified:             bootstrap.sh
  Log:
  Remove call to emerge --clean.
  
  Since AUTOCLEAN=yes is the default, there's no need to call emerge
  --clean. Also, remove redundant AUTOCLEAN=yes export, since that's
  the default and if the user has disabled AUTOCLEAN then that's their
  problem.

Revision  Changes    Path
1.97                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.97&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.97&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.96&r2=1.97

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.96
retrieving revision 1.97
diff -u -r1.96 -r1.97
--- bootstrap.sh	23 Oct 2012 02:25:23 -0000	1.96
+++ bootstrap.sh	27 Jun 2013 21:04:49 -0000	1.97
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2012 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.96 2012/10/23 02:25:23 zmedico Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.97 2013/06/27 21:04:49 zmedico Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.96 2012/10/23 02:25:23 zmedico Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.97 2013/06/27 21:04:49 zmedico Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -304,10 +304,6 @@
 [[ -x /usr/sbin/gcc-config ]] && GCC_CONFIG="/usr/sbin/gcc-config"
 [[ -x /usr/bin/gcc-config  ]] && GCC_CONFIG="/usr/bin/gcc-config"
 
-# Make sure we automatically clean old instances, else we may run
-# into issues, bug #32140.
-export AUTOCLEAN="yes"
-
 # Allow portage to overwrite stuff
 export CONFIG_PROTECT="-*"
 
@@ -350,7 +346,6 @@
 	if [[ -x ${GCC_CONFIG} ]] && ${GCC_CONFIG} --get-current-profile &>/dev/null
 	then
 		# Make sure we get the old gcc unmerged ...
-		emerge --clean || cleanup 1
 		emerge --prune sys-devel/gcc || cleanup 1
 		# Make sure the profile and /lib/cpp and /usr/bin/cc are valid ...
 		${GCC_CONFIG} "$(${GCC_CONFIG} --get-current-profile)" &>/dev/null





^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2014-03-13 16:11 William Hubbs (williamh)
  0 siblings, 0 replies; 13+ messages in thread
From: William Hubbs (williamh) @ 2014-03-13 16:11 UTC (permalink / raw
  To: gentoo-commits

williamh    14/03/13 16:11:27

  Modified:             bootstrap.sh
  Log:
  We should attempt to source /lib/gentoo/functions.sh before we attempt
  to source /etc/init.d/functions.sh.
  Also, we should unconditionally define our own esyslog function.
  This is for bug #504376.

Revision  Changes    Path
1.98                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.98&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.98&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.97&r2=1.98

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.97
retrieving revision 1.98
diff -u -r1.97 -r1.98
--- bootstrap.sh	27 Jun 2013 21:04:49 -0000	1.97
+++ bootstrap.sh	13 Mar 2014 16:11:27 -0000	1.98
@@ -1,7 +1,7 @@
 #!/bin/bash
-# Copyright 1999-2012 Gentoo Foundation
+# Copyright 1999-2014 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.97 2013/06/27 21:04:49 zmedico Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.98 2014/03/13 16:11:27 williamh Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -12,23 +12,26 @@
 # (azarah, Mar 2005)
 # (uberlord, May 2007)
 # (kumba, May 2007)
+# (williamh, Mar 2014)
 
 # sanity check
 [[ -e /etc/profile ]] && . /etc/profile
 
-if [[ -e /etc/init.d/functions.sh ]] ; then
+if [[ -e /lib/gentoo/functions.sh ]] ; then
+	source /lib/gentoo/functions.sh
+	elif [[ -e /etc/init.d/functions.sh ]] ; then
 	source /etc/init.d/functions.sh
-
-	# Use our own custom script, else logger cause things to
-	# 'freeze' if we do not have a system logger running
-	esyslog() {
-		:
-	}
 else
 	eerror() { echo "!!! $*"; }
 	einfo() { echo "* $*"; }
 fi
 
+# Use our own custom script, else logger cause things to
+# 'freeze' if we do not have a system logger running
+esyslog() {
+	:
+}
+
 show_status() {
 	local num=$1
 	shift
@@ -52,7 +55,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.97 2013/06/27 21:04:49 zmedico Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.98 2014/03/13 16:11:27 williamh Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }





^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2015-02-04 10:07 Joshua Kinard (kumba)
  0 siblings, 0 replies; 13+ messages in thread
From: Joshua Kinard (kumba) @ 2015-02-04 10:07 UTC (permalink / raw
  To: gentoo-commits

kumba       15/02/04 10:07:32

  Modified:             bootstrap.sh
  Log:
  Fix to call emerge --resume properly, especially for catalyst stage2 resumes.  #538618.

Revision  Changes    Path
1.99                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.99&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.99&content-type=text/plain
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.98&r2=1.99

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.98
retrieving revision 1.99
diff -u -r1.98 -r1.99
--- bootstrap.sh	13 Mar 2014 16:11:27 -0000	1.98
+++ bootstrap.sh	4 Feb 2015 10:07:32 -0000	1.99
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2014 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.98 2014/03/13 16:11:27 williamh Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.99 2015/02/04 10:07:32 kumba Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -13,6 +13,7 @@
 # (uberlord, May 2007)
 # (kumba, May 2007)
 # (williamh, Mar 2014)
+# (kumba, Feb 2015)
 
 # sanity check
 [[ -e /etc/profile ]] && . /etc/profile
@@ -55,7 +56,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.98 2014/03/13 16:11:27 williamh Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.99 2015/02/04 10:07:32 kumba Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -333,13 +334,11 @@
 		STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} --resume"
 		cp /var/run/bootstrap-mtimedb /var/cache/edb
 	else
-		# Why do we need this?  It will pull in python that needs g++
-		# among others, and add a few IMHO unneeded deps ...
-		#STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} -e"
-		:
+		STRAP_EMERGE_OPTS="${STRAP_EMERGE_OPTS} \
+			${myOS_HEADERS} ${myTEXINFO} ${myGETTEXT} ${myBINUTILS} \
+			${myGCC} ${myLIBC} ${myBASELAYOUT} ${myZLIB}"
 	fi
-	${V_ECHO} emerge ${STRAP_EMERGE_OPTS} ${myOS_HEADERS} ${myTEXINFO} ${myGETTEXT} ${myBINUTILS} \
-		${myGCC} ${myLIBC} ${myBASELAYOUT} ${myZLIB} || cleanup 1
+	${V_ECHO} emerge ${STRAP_EMERGE_OPTS} || cleanup 1
 	echo -------------------------------------------------------------------------------
 	set_bootstrap_stage 3
 fi





^ permalink raw reply	[flat|nested] 13+ messages in thread

end of thread, other threads:[~2015-02-04 10:07 UTC | newest]

Thread overview: 13+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2011-07-14  1:24 [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh Jorge Manuel B. S. Vicetto (jmbsvicetto)
  -- strict thread matches above, loose matches on Subject: below --
2015-02-04 10:07 Joshua Kinard (kumba)
2014-03-13 16:11 William Hubbs (williamh)
2013-06-27 21:04 Zac Medico (zmedico)
2012-10-23  2:25 Zac Medico (zmedico)
2012-07-07  3:34 Mike Frysinger (vapier)
2011-11-17  1:51 Jorge Manuel B. S. Vicetto (jmbsvicetto)
2011-07-14 19:19 Zac Medico (zmedico)
2011-05-20  3:05 Jorge Manuel B. S. Vicetto (jmbsvicetto)
2010-09-11 17:06 Zac Medico (zmedico)
2009-09-25  5:17 Zac Medico (zmedico)
2009-08-06 22:21 Zac Medico (zmedico)
2008-03-30 16:51 Mike Frysinger (vapier)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?r1=1.93&r2=1.94

Index: bootstrap.sh
===================================================================
RCS file: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v
retrieving revision 1.93
retrieving revision 1.94
diff -u -r1.93 -r1.94
--- bootstrap.sh	14 Jul 2011 19:19:02 -0000	1.93
+++ bootstrap.sh	17 Nov 2011 01:51:06 -0000	1.94
@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2007 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.93 2011/07/14 19:19:02 zmedico Exp $
+# $Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.94 2011/11/17 01:51:06 jmbsvicetto Exp $
 
 # people who were here:
 # (drobbins, 06 Jun 2003)
@@ -52,7 +52,7 @@
 	env "$@"
 }
 
-cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.93 2011/07/14 19:19:02 zmedico Exp $"
+cvsver="$Header: /var/cvsroot/gentoo-x86/scripts/bootstrap.sh,v 1.94 2011/11/17 01:51:06 jmbsvicetto Exp $"
 cvsver=${cvsver##*,v }
 cvsver=${cvsver%%Exp*}
 cvsyear=${cvsver#* }
@@ -304,16 +304,16 @@
 # disable collision-protection
 export FEATURES="${FEATURES} -collision-protect"
 
-# query STAGE1_USE from the profile
-STAGE1_USE=$(portageq envvar STAGE1_USE)
+# query BOOTSTRAP_USE from the profile
+BOOTSTRAP_USE=$(portageq envvar BOOTSTRAP_USE)
 
 if [ ${BOOTSTRAP_STAGE} -le 1 ] ; then
 	show_status 2 Updating portage
-	${V_ECHO} USE="-* build bootstrap ${ALLOWED_USE} ${STAGE1_USE}" emerge ${STRAP_EMERGE_OPTS} ${myPORTAGE} || cleanup 1
+	${V_ECHO} USE="-* build bootstrap ${ALLOWED_USE} ${BOOTSTRAP_USE}" emerge ${STRAP_EMERGE_OPTS} ${myPORTAGE} || cleanup 1
 	echo -------------------------------------------------------------------------------
 	set_bootstrap_stage 2
 fi
-export USE="-* bootstrap ${ALLOWED_USE} ${STAGE1_USE}"
+export USE="-* bootstrap ${ALLOWED_USE} ${BOOTSTRAP_USE}"
 
 # We can't unmerge headers which may or may not exist yet. If your
 # trying to use nptl, it may be needed to flush out any old headers






^ permalink raw reply	[flat|nested] 13+ messages in thread

* [gentoo-commits] gentoo-x86 commit in scripts: bootstrap.sh
@ 2012-07-07  3:34 Mike Frysinger (vapier)
  0 siblings, 0 replies; 13+ messages in thread
From: Mike Frysinger (vapier) @ 2012-07-07  3:34 UTC (permalink / raw
  To: gentoo-commits

vapier      12/07/07 03:34:53

  Modified:             bootstrap.sh
  Log:
  check /etc/portage/make.profile and /etc/make.profile #424235

Revision  Changes    Path
1.95                 scripts/bootstrap.sh

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.95&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/scripts/bootstrap.sh?rev=1.95&content-type=text/plain